@@ -1,5 +1,6 @@
 from django.contrib.admin import site
-from nango.contrib.admin import ModelAdmin
+
+from .admin import ModelAdmin
 
 
 def register(model):
